@@ -37,10 +37,11 @@ class App(tk.Tk):
         self.sizegrip.grid(row=1, column=1, padx=5, pady=5)
 
         # Set Minimun Size
-        self.minsize(int(self.winfo_screenwidth() / 2), int(self.winfo_screenheight() * 5 / 6))
-        x_coordinate = int(self.winfo_screenwidth() / 4)
-        y_coordinate = int(self.winfo_screenheight() / 12)
+        self.minsize(900, 900)
+        x_coordinate = int(max(self.winfo_screenwidth() / 2 - 450, 10))
+        y_coordinate = int(max(self.winfo_screenheight() / 2 - 470, 10))
         self.geometry("+{}+{}".format(x_coordinate, y_coordinate))
+
     
     def swtich_mode(self, darkmode):
         
