@@ -1,5 +1,6 @@
 import tkinter as tk
 from tkinter import ttk
+import webbrowser
 
 from biostats.datasets import dataset
 
@@ -14,7 +15,7 @@ class Example(ttk.Menubutton):
         # Variable
         self.test_type = ["Basic", "t-Test", "ANOVA", "Exact Test", "Chi-Square Test", "Linear Regression", "Logistic Regression", "Nonparametric", "Others"]
         self.test_list = {
-            "Basic"               : ["Numeral", "Numeral (Grouped)", "Categorical", "Contingency"] ,
+            "Basic"               : ["Numeric", "Numeric (Grouped)", "Categorical", "Contingency"] ,
             "t-Test"              : ["One-Sample t-Test", "Two-Sample t-Test", "Paired t-Test", "Pairwise t-Test"] ,
             "ANOVA"               : ["One-Way ANOVA", "Two-Way ANOVA", "One-Way ANCOVA", "Two-Way ANCOVA", "Multivariate ANOVA", "Repeated Measures ANOVA"] ,
             "Exact Test"          : ["Binomial Test", "Fisher's Exact Test", "McNemar's Exact Test"] ,
@@ -62,24 +63,24 @@ class Example(ttk.Menubutton):
 
         which = self.which.get()
 
-        if which == "Numeral":
-            self.master.data_win.data_process(dataset("numeral.csv"))
+        if which == "Numeric":
+            self.master.data_win.data_process(dataset("numeric.csv"))
             self.master.window.set(1)
             self.master.switch()
             self.master.test_win.test_1.set("Basic")
-            self.master.test_win.test_2["Basic"].set("Numeral")
+            self.master.test_win.test_2["Basic"].set("Numeric")
             self.master.test_win.test_change()
             self.master.test_win.option[0].check_more_var[0].set(1)
             self.master.test_win.option[0].check_more_var[1].set(1)
             self.master.test_win.option[0].check_more_var[2].set(1)
             self.master.test_win.change()
         
-        if which == "Numeral (Grouped)":
-            self.master.data_win.data_process(dataset("numeral_grouped.csv"))
+        if which == "Numeric (Grouped)":
+            self.master.data_win.data_process(dataset("numeric_grouped.csv"))
             self.master.window.set(1)
             self.master.switch()
             self.master.test_win.test_1.set("Basic")
-            self.master.test_win.test_2["Basic"].set("Numeral (Grouped)")
+            self.master.test_win.test_2["Basic"].set("Numeric (Grouped)")
             self.master.test_win.test_change()
             self.master.test_win.option[0].radio_one_var.set(0)
             self.master.test_win.change()
@@ -255,7 +256,7 @@ class Example(ttk.Menubutton):
             self.master.test_win.option[1].radio_one_var.set(1)
             self.master.test_win.change()
             self.master.test_win.option[2].radio_one_var.set(2)
-            self.master.test_win.change()
+            self.master.test_win.change()     
 
         if which == "Binomial Test":
             self.master.data_win.data_process(dataset("binomial_test.csv"))
@@ -283,6 +284,8 @@ class Example(ttk.Menubutton):
             self.master.test_win.change()
             self.master.test_win.option[1].radio_one_var.set(1)
             self.master.test_win.change()
+            self.master.test_win.option[2].radio_one_var.set(2)
+            self.master.test_win.change()
 
         if which == "McNemar's Exact Test":
             self.master.data_win.data_process(dataset("mcnemar_exact_test.csv"))
@@ -309,6 +312,8 @@ class Example(ttk.Menubutton):
             self.master.test_win.change()
             self.master.test_win.option[1].radio_one_var.set(1)
             self.master.test_win.change()
+            self.master.test_win.option[2].radio_one_var.set(2)
+            self.master.test_win.change()
 
         if which == "Chi-Square Test (Fit)":
             self.master.data_win.data_process(dataset("chi_square_test_fit.csv"))
@@ -731,9 +736,9 @@ class Example(ttk.Menubutton):
             self.master.plot_win.plot_1.set("Categorical")
             self.master.plot_win.plot_2["Categorical"].set("Count Plot")
             self.master.plot_win.plot_change()
-            self.master.plot_win.option[0].radio_one_var.set(6)
+            self.master.plot_win.option[0].radio_one_var.set(9)
             self.master.plot_win.change()
-            self.master.plot_win.option[1].radio_one_var.set(8)
+            self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Strip Plot":
@@ -747,7 +752,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Swarm Plot":
@@ -761,7 +766,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Box Plot":
@@ -775,7 +780,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Boxen Plot":
@@ -789,7 +794,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Violin Plot":
@@ -803,7 +808,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Bar Plot":
@@ -817,7 +822,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(0)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(2)
+            self.master.plot_win.option[2].radio_one_var.set(0)
             self.master.plot_win.change()
 
         if which == "Scatter Plot":
@@ -831,7 +836,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(1)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(4)
+            self.master.plot_win.option[2].radio_one_var.set(3)
             self.master.plot_win.change()
 
         if which == "Line Plot":
@@ -934,7 +939,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.change()
             self.master.plot_win.option[1].radio_one_var.set(1)
             self.master.plot_win.change()
-            self.master.plot_win.option[2].radio_one_var.set(0)
+            self.master.plot_win.option[2].radio_one_var.set(1)
             self.master.plot_win.change()
 
         if which == "PCA Plot":
@@ -949,7 +954,7 @@ class Example(ttk.Menubutton):
             self.master.plot_win.option[0].check_more_var[2].set(1)
             self.master.plot_win.option[0].check_more_var[3].set(1)
             self.master.plot_win.change()
-            self.master.plot_win.option[1].radio_one_var.set(0)
+            self.master.plot_win.option[1].radio_one_var.set(1)
             self.master.plot_win.change()
 
         if which == "LDA Plot":
@@ -981,4 +986,7 @@ class Manual(ttk.Menubutton):
 
     def setup(self):
 
-        pass
+        self.menu_0 = tk.Menu(self)
+        self.config(menu=self.menu_0)
+
+        self.menu_0.add_command(label="Official Site", command=lambda: webbrowser.open("https://hikarimusic.github.io/BIOSTATS/"))
